<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<link rel="stylesheet" href="{{ static_url('ztq_console:static/style.css') }}" type="text/css" />
</head>
<body>
    <div id='header'>
        <h1>{{title}}</h1>
        <div class="powered">
            Powered by <a href="http://everydo.com/" target="_blank">Everydo.com</a>
        </div>
        <div class="clear"></div>
   </div>
</body>
</html>
