/*
KISSY CSS Reset
理念：清除和重置是紧密不可分的
特色：1.适应中文 2.基于最新主流浏览器
维护：玉伯(lifesinger@gmail.com), 正淳(ragecarrier@gmail.com)
*/

/* 清除内外边距 */
body, h1, h2, h3, h4, h5, h6, p, blockquote, /* structural elements 结构元素 */
dl, dt, dd, ul, ol, li, /* list elements 列表元素 */
pre, /* text formatting elements 文本格式元素 */
fieldset, lengend, button, input, textarea, /* form elements 表单元素 */
th, td { /* table elements 表格元素 */
    margin: 0;
    padding: 0;
}

/* 设置默认字体 */
body,
button, input, select, textarea, table { /* for ie */
    /*font: 12px/1 Tahoma, Helvetica, Arial, "宋体", sans-serif;*/
    font: 13px/1 Arial,Verdana,sans-serif; /* 用 ascii 字符表示，使得在任何编码下都无问题 */
}
button, input, select, textarea { padding:3px; line-height:1em; margin:0;}
input { line-height:normal; }
h1 { font-size:24px; }
h2 { font-size:22px; }
h3 { font-size:20px; }
h4 { font-size:18px; }
h5 { font-size:15px; }
h1, h2, h3, h4, h5 { font-weight:normal; }

address, cite, dfn, var { font-style: normal; } /* 将斜体扶正 */
small { font-size: 11px; } /* 小于 12px 的中文很难阅读，让 small 正常化 */

/* 重置文本格式元素 */

abbr[title], acronym[title] { /* 注：1.ie6 不支持 abbr; 2.这里用了属性选择符，ie6 下无效果 */
	border-bottom: 1px dotted;
	cursor: help;
}

q:before, q:after { content: ''; }

/* 重置表单元素 */
legend { color: #000; } /* for ie6 */
fieldset, img { border: none; } /* img 搭车：让链接里的 img 无边框 */
/* 注：optgroup 无法扶正 */
button, input, select, textarea {
    font-size: 100%; /* 使得表单元素在 ie 下能继承字体大小 */
}

/* 重置表格元素 */
table {
	border-collapse: collapse;
	border-spacing: 0;
}

/* 让非ie浏览器默认也显示垂直滚动条，防止因滚动条引起的闪烁 */
/*html { overflow-y: scroll; }*/

/* reset end */





/*--------------------------------------------------------*/

a { color:#3366CC; }
a:hover { color:#BD0A01; }

body { }
pre { font-family:'Courier New',sans-serif; }
.no-wrap { white-space:nowrap; }
.bt { background:#EEE; color:#333; border:1px solid #CCC; border-radius:5px; padding:3px 5px; }
    a.bt { text-decoration:none; }
    a.bt:hover { background:#CCC; border:1px slid #999; }
.red { color:red; }
.selected a { color:red !important; }
.clear { clear:both; }

/* begin header*/
#header{ border-bottom:5px solid #4396C3; padding:5px; background:url(images/header-bg.jpg) repeat-x; }
    #header h1 { background:url(images/logo.gif) no-repeat left center; font-size:42px; line-height:60px; padding:0 0 0 60px; color:#666; float:left; }
    .powered { float:right; color:#666; padding-top:40px; }

/* begin menu*/
.menu{ width:800px;margin:20;font-size:15px; }

#menu { padding:5px 10px; border-radius:3px; background:#EDF5FA; margin:0 10px; }
    #menu p { padding:10px 5px; font-size:14px; font-weight:700; border-bottom:1px solid #CCC;}
    #menu p a { text-decoration:none; color:#000; }
    #menu p a:hover { color:red; }

/* content page title */
#discribe{ margin-bottom:20px; font-size:24px; }

#status-section{ }
    #status-section table { border-spacing: 0; width: 100%; table-layout: fixed; }
        #status-section table td { word-wrap:break-word; }
        #status-section th { border: 1px solid #CCC; padding:10px; text-align:left;background:#F5F5F5; font-size:13px; white-space:nowrap; }
        #status-section td { border-bottom: 1px solid #CCC; padding:10px; vertical-align:top; }

#content{ position:absolute; width:80%; height:80%; left: 250px; top: 80px; }

#iframe1{ width:100%; height:100%; }

#sibebar{ position:absolute; top:80px; left:-15px; font-size:15px; }
    #sibebar ul li { float: inherit; border-bottom:5px; list-style: none; }
    #sibebar ul li a:hover { top: 10px; color: #a9a779; text-decoration:underline; }

.show_code { text-align: left; }
