<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<link rel="stylesheet" href="{{ static_url('ztq_console:static/style.css') }}" type="text/css" />
</head>
<BODY>
<div id="menu">
    {% for link in links %}
        <p><a href="{{ link[0] }}" target="content" onclick="c({{ links.index(link)}})">{{ link[1] }}</a></p>
    {% endfor %}
</div>
<script>
    function c(index){
        var allP = document.getElementById('menu').getElementsByTagName('p');
        for(var i = 0; i<allP.length; i++){
            if(index == i){  
                allP[i].className = 'selected';
            }
            else{
                 allP[i].className = '';
            }
        }
    }
</script>
</BODY></HTML>
