#coding:utf-8
"""
Created on 2011-4-12

@author: Zay
"""
#原子队列信息
TASK_QUEUES = [    
         {'name':'q01', 'title':'q01', 
          'tags':(['small','doc-html','form'],['big','doc-txt','form']),'weight':5},
               ]


