h1 { /* table elements 表格元素 */
    margin: 0;
    padding: 0;
}
h1 { font-size:24px; }
h1 { font-weight:normal; }

label {
    width: 150px;
    padding-top: 2px;
    display:inline-block;
    text-align: right;
    padding-right:10px;
}

.info {
    color:gray;
    font-size: 12px;
}

select {
    display: span;
}

li{
  list-style:none;
  margin-top:3px;
} 


.button {
    position: relative;
    /* overflow: visible; */
    display: inline-block;
    padding: 0.5em 1em;
    *padding-left:0.5em;
    *padding-right:0.5em;
    padding-bottom: 0.3em\9;
    border: 1px solid #d4d4d4;
    margin: 0;
    text-decoration: none;
    text-shadow: 1px 1px 0 #fff;
    /*font:11px/normal sans-serif;*/
    font-size: 12px;
    font-size: 11px\9; /* Only IE */
    color: #333;
    white-space: nowrap;
    cursor: pointer;
    outline: none;
    background-color: #ececec;
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f4f4f4), to(#ececec));
    background-image: -moz-linear-gradient(#f4f4f4, #ececec);
    background-image: -o-linear-gradient(#f4f4f4, #ececec);
    background-image: linear-gradient(#f4f4f4, #ececec);
    -webkit-background-clip: padding;
    -moz-background-clip: padding;
    -o-background-clip: padding-box;
    /*background-clip: padding-box;*/ /* commented out due to Opera 11.10 bug */
    -webkit-border-radius: 0.2em;
    -moz-border-radius: 0.2em;
    border-radius: 0.2em;
    /* IE hacks */
    zoom: 1;
    *display: inline;
}

.button:hover,
.button:focus,
.button:active,
.button.active {
    border-color: #3072b3;
    border-bottom-color: #2a65a0;
    text-decoration: none;
    text-shadow: -1px -1px 0 rgba(0,0,0,0.3);
    color: #fff !important;
    background-color: #3C8DDE;
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#599bdc), to(#3072b3));
    background-image: -moz-linear-gradient(#599bdc, #3072b3);
    background-image: -o-linear-gradient(#599bdc, #3072b3);
    background-image: linear-gradient(#599bdc, #3072b3);
}

.button:active,
.button.active {
    border-color: #2a65a0;
    border-bottom-color: #3884CF;
    background-color: #3072b3;
    background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#3072b3), to(#599bdc));
    background-image: -moz-linear-gradient(#3072b3, #599bdc);
    background-image: -o-linear-gradient(#3072b3, #599bdc);
    background-image: linear-gradient(#3072b3, #599bdc);
    _background:#3884CF !important;
    _border:1px solid #2A65A0 !important;
}

/* overrides extra padding on button elements in Firefox */
.button::-moz-focus-inner {
    padding: 0;
    border: 0;
}

a:link {
    color: blue;
}

input[type='text'] {
	width:300px
}

input[type='password'] {
	width:300px
}

input {
    width:expression(this.type=="text"?"300px":"style");
}
